package com.mdd.admin.controller.setting;

import com.mdd.admin.service.ISettingPaymentService;
import com.mdd.admin.validate.setting.SettingPayConfigValidate;
import com.mdd.admin.validate.setting.SettingPayMethodValidate;
import com.mdd.admin.vo.setting.SettingPaymentMethodVo;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.entity.setting.DevPayConfig;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/setting/payment"})
@Api(
   tags = {"配置支付参数"}
)
public class SettingPaymentController {
   @Resource
   ISettingPaymentService iSettingPaymentService;

   @GetMapping({"/method"})
   @ApiOperation("支付方式列表")
   public AjaxResult<List<List<SettingPaymentMethodVo>>> method() {
      List<List<SettingPaymentMethodVo>> list = this.iSettingPaymentService.method();
      return AjaxResult.success(list);
   }

   @GetMapping({"/list"})
   @ApiOperation("支付配置列表")
   public AjaxResult<List<DevPayConfig>> list() {
      List<DevPayConfig> list = this.iSettingPaymentService.list();
      return AjaxResult.success(list);
   }

   @GetMapping({"/detail"})
   @ApiOperation("支付配置详情")
   public AjaxResult<Object> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      DevPayConfig vo = this.iSettingPaymentService.detail(id);
      return AjaxResult.success(vo);
   }

   @PostMapping({"/editConfig"})
   @ApiOperation("支付配置编辑")
   public AjaxResult<Object> editConfig(@Validated @RequestBody SettingPayConfigValidate configValidate) {
      this.iSettingPaymentService.editConfig(configValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/editMethod"})
   @ApiOperation("支付方式编辑")
   public AjaxResult<Object> editMethod(@Validated @RequestBody SettingPayMethodValidate methodValidate) {
      this.iSettingPaymentService.editMethod(methodValidate);
      return AjaxResult.success();
   }
}
